import tkinter as tk
from tkinter import filedialog, messagebox
from PIL import Image

class ImageToPDFApp:
    def __init__(self, root):
        self.root = root
        self.root.title("Image to PDF Merger")

        self.file_list = []

        self.listbox = tk.Listbox(root, selectmode=tk.SINGLE, width=120)
        self.listbox.pack(padx=10, pady=10)

        button_frame = tk.Frame(root)
        button_frame.pack()

        tk.Button(button_frame, text="Add Images", command=self.add_images).grid(row=0, column=0, padx=5)
        tk.Button(button_frame, text="Remove Selected", command=self.remove_selected).grid(row=0, column=1, padx=5)
        tk.Button(button_frame, text="Move Up", command=self.move_up).grid(row=0, column=2, padx=5)
        tk.Button(button_frame, text="Move Down", command=self.move_down).grid(row=0, column=3, padx=5)
        tk.Button(button_frame, text="Save as PDF", command=self.save_pdf).grid(row=0, column=4, padx=5)

    def add_images(self):
        files = filedialog.askopenfilenames(
            title="Select Image Files",
            filetypes=[("Image files", "*.png *.jpg *.jpeg *.bmp *.tiff")]
        )
        for f in files:
            if f not in self.file_list:
                self.file_list.append(f)
                self.listbox.insert(tk.END, f)

    def remove_selected(self):
        selected = self.listbox.curselection()
        if selected:
            idx = selected[0]
            del self.file_list[idx]
            self.listbox.delete(idx)

    def move_up(self):
        selected = self.listbox.curselection()
        if selected and selected[0] > 0:
            idx = selected[0]
            self.file_list[idx - 1], self.file_list[idx] = self.file_list[idx], self.file_list[idx - 1]
            self.refresh_listbox(idx - 1)

    def move_down(self):
        selected = self.listbox.curselection()
        if selected and selected[0] < len(self.file_list) - 1:
            idx = selected[0]
            self.file_list[idx + 1], self.file_list[idx] = self.file_list[idx], self.file_list[idx + 1]
            self.refresh_listbox(idx + 1)

    def refresh_listbox(self, new_selection):
        self.listbox.delete(0, tk.END)
        for f in self.file_list:
            self.listbox.insert(tk.END, f)
        self.listbox.select_set(new_selection)

    def save_pdf(self):
        if not self.file_list:
            messagebox.showerror("Error", "No images selected.")
            return

        output_path = filedialog.asksaveasfilename(
            defaultextension=".pdf",
            filetypes=[("PDF files", "*.pdf")],
            title="Save PDF as..."
        )
        if not output_path:
            return

        try:
            images = [Image.open(f).convert("RGB") for f in self.file_list]
            images[0].save(output_path, save_all=True, append_images=images[1:])
            messagebox.showinfo("Success", f"PDF saved as:\n{output_path}")
        except Exception as e:
            messagebox.showerror("Error", f"Failed to save PDF:\n{e}")

if __name__ == "__main__":
    root = tk.Tk()
    app = ImageToPDFApp(root)
    root.mainloop()
